@@ -169,7 +169,7 @@ SEXP attribute_hidden do_deparse(SEXP call, SEXP op, SEXP args, SEXP rho)
     args = CDR(args);
     opts = SHOWATTRIBUTES;
     if(!isNull(CAR(args)))
-    	opts = asInteger(CAR(args));
+	opts = asInteger(CAR(args));
     args = CDR(args);
     nlines = asInteger(CAR(args));
     if (nlines == NA_INTEGER) nlines = -1;
@@ -181,7 +181,7 @@ SEXP deparse1(SEXP call, Rboolean abbrev, int opts)
 {
     Rboolean backtick = TRUE;
     return deparse1WithCutoff(call, abbrev, DEFAULT_Cutoff, backtick,
-    			      opts, -1);
+			      opts, -1);
 }
 
 static SEXP deparse1WithCutoff(SEXP call, Rboolean abbrev, int cutoff,
@@ -234,11 +234,11 @@ static SEXP deparse1WithCutoff(SEXP call, Rboolean abbrev, int cutoff,
     }
     R_print.digits = savedigits;
     if ((opts & WARNINCOMPLETE) && localData.isS4)
-    	warning(_("deparse of an S4 object will not be source()able"));
+	warning(_("deparse of an S4 object will not be source()able"));
     else if ((opts & WARNINCOMPLETE) && !localData.sourceable)
-    	warning(_("deparse may be incomplete"));
+	warning(_("deparse may be incomplete"));
     if ((opts & WARNINCOMPLETE) && localData.longstring)
-    	warning(_("deparse may be not be source()able in R < 2.7.0"));
+	warning(_("deparse may be not be source()able in R < 2.7.0"));
     /* somewhere lower down might have allocated ... */
     R_FreeStringBuffer(&(localData.buffer));
     return svec;
@@ -254,7 +254,7 @@ SEXP deparse1line(SEXP call, Rboolean abbrev)
    Rboolean backtick=TRUE;
 
    temp = deparse1WithCutoff(call, abbrev, MAX_Cutoff, backtick,
-   			     SIMPLEDEPARSE, 1);
+			     SIMPLEDEPARSE, 1);
    return(temp);
 }
 
@@ -264,7 +264,7 @@ SEXP attribute_hidden deparse1s(SEXP call)
    Rboolean backtick=TRUE;
 
    temp = deparse1WithCutoff(call, FALSE, DEFAULT_Cutoff, backtick,
-   			     DEFAULTDEPARSE, 1);
+			     DEFAULTDEPARSE, 1);
    return(temp);
 }
 
@@ -287,13 +287,14 @@ SEXP attribute_hidden do_dput(SEXP call, SEXP op, SEXP args, SEXP rho)
     }
     opts = SHOWATTRIBUTES;
     if(!isNull(CADDR(args)))
-       	opts = asInteger(CADDR(args));
+	opts = asInteger(CADDR(args));
 
     tval = deparse1(tval, 0, opts);
     if (TYPEOF(CAR(args)) == CLOSXP) {
 	SET_CLOENV(CAR(args), saveenv);
 	UNPROTECT(1);
     }
+    PROTECT(tval); /* against Rconn_printf */
     ifile = asInteger(CADR(args));
 
     wasopen = 1;
@@ -312,6 +313,7 @@ SEXP attribute_hidden do_dput(SEXP call, SEXP op, SEXP args, SEXP rho)
 	       res < strlen(CHAR(STRING_ELT(tval, i))) + 1)
 		warning(_("wrote too few characters"));
 	}
+    UNPROTECT(1); /* tval */
     if (!wasopen) con->close(con);
     return (CAR(args));
 }
@@ -338,7 +340,7 @@ SEXP attribute_hidden do_dump(SEXP call, SEXP op, SEXP args, SEXP rho)
     if (source != R_NilValue && TYPEOF(source) != ENVSXP)
 	error(_("invalid '%s' argument"), "envir");
     opts = asInteger(CADDDR(args));
-    /* <NOTE>: change this if extra options are added */ 
+    /* <NOTE>: change this if extra options are added */
     if(opts == NA_INTEGER || opts < 0 || opts > 256)
 	errorcall(call, _("'opts' should be small non-negative integer"));
     evaluate = asLogical(CAD4R(args));
@@ -451,8 +453,8 @@ static Rboolean needsparens(PPinfo mainop, SEXP arg, unsigned int left)
 		case PP_BINARY2:
 		    switch(length(CDR(arg))) {
 		    case 1:
-		    	if (!left)
-		    	    return FALSE;
+			if (!left)
+			    return FALSE;
 			if (arginfo.precedence == PREC_SUM)   /* binary +/- precedence upgraded as unary */
 			    arginfo.precedence = PREC_SIGN;
 		    case 2:
@@ -497,10 +499,10 @@ static Rboolean hasAttributes(SEXP s)
     SEXP a = ATTRIB(s);
     if (length(a) > 2) return(TRUE);
     while(!isNull(a)) {
-    	if(TAG(a) != R_SrcrefSymbol
-    	   && (TYPEOF(s) != CLOSXP || TAG(a) != R_SourceSymbol))
-    	    return(TRUE);
-    	a = CDR(a);
+	if(TAG(a) != R_SrcrefSymbol
+	   && (TYPEOF(s) != CLOSXP || TAG(a) != R_SourceSymbol))
+	    return(TRUE);
+	a = CDR(a);
     }
     return(FALSE);
 }
@@ -643,7 +645,7 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 	print2buff("NULL", d);
 	break;
     case SYMSXP:
-    	if (localOpts & QUOTEEXPRESSIONS) {
+	if (localOpts & QUOTEEXPRESSIONS) {
 	    attr1(s, d);
 	    print2buff("quote(", d);
 	}
@@ -685,13 +687,13 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 	}
 	break;
     case CLOSXP:
-        if (localOpts & SHOWATTRIBUTES) attr1(s, d);
-        if ((d->opts & USESOURCE) && 
-	    (n = length(t = getAttrib(s, R_SourceSymbol))) > 0 
+	if (localOpts & SHOWATTRIBUTES) attr1(s, d);
+	if ((d->opts & USESOURCE) &&
+	    (n = length(t = getAttrib(s, R_SourceSymbol))) > 0
 	    && isString(t)) {
-    	    for(i = 0 ; i < n ; i++) {
-	    	print2buff(translateChar(STRING_ELT(t, i)), d);
-	    	writeline(d);
+	    for(i = 0 ; i < n ; i++) {
+		print2buff(translateChar(STRING_ELT(t, i)), d);
+		writeline(d);
 	    }
 	} else {
 	    /* We have established that we don't want to use the
@@ -708,7 +710,7 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 	if (localOpts & SHOWATTRIBUTES) attr2(s, d);
 	break;
     case ENVSXP:
-        d->sourceable = FALSE;
+	d->sourceable = FALSE;
 	print2buff("<environment>", d);
 	break;
     case VECSXP:
@@ -719,7 +721,7 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 	if (localOpts & SHOWATTRIBUTES) attr2(s, d);
 	break;
     case EXPRSXP:
-    	if (localOpts & SHOWATTRIBUTES) attr1(s, d);
+	if (localOpts & SHOWATTRIBUTES) attr1(s, d);
 	if(length(s) <= 0)
 	    print2buff("expression()", d);
 	else {
@@ -895,17 +897,17 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 		case PP_FUNCTION:
 		    printcomment(s, d);
 		    if (!(d->opts & USESOURCE) || !isString(CADDR(s))) {
-		    	print2buff(CHAR(PRINTNAME(op)), d); /* ASCII */
-		    	print2buff("(", d);
-		    	args2buff(FORMALS(s), 0, 1, d);
-		    	print2buff(") ", d);
-		    	deparse2buff(CADR(s), d);
+			print2buff(CHAR(PRINTNAME(op)), d); /* ASCII */
+			print2buff("(", d);
+			args2buff(FORMALS(s), 0, 1, d);
+			print2buff(") ", d);
+			deparse2buff(CADR(s), d);
 		    } else {
 			s = CADDR(s);
 			n = length(s);
-	    	    	for(i = 0 ; i < n ; i++) {
-	    		    print2buff(translateChar(STRING_ELT(s, i)), d);
-	    		    writeline(d);
+			for(i = 0 ; i < n ; i++) {
+			    print2buff(translateChar(STRING_ELT(s, i)), d);
+			    writeline(d);
 			}
 		    }
 		    break;
@@ -1029,15 +1031,15 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 		    if ( isSymbol(CAR(s))
 		      && TYPEOF(val) == CLOSXP
 		      && streql(CHAR(PRINTNAME(CAR(s))), "::") ){ /*  :: is special case */
-		    	deparse2buff(CADR(s), d);
-		    	print2buff("::", d);
+			deparse2buff(CADR(s), d);
+			print2buff("::", d);
 			deparse2buff(CADDR(s), d);
 		    }
 		    else if ( isSymbol(CAR(s))
 		      && TYPEOF(val) == CLOSXP
 		      && streql(CHAR(PRINTNAME(CAR(s))), ":::") ){ /*  ::: is special case */
-		    	deparse2buff(CADR(s), d);
-		    	print2buff(":::", d);
+			deparse2buff(CADR(s), d);
+			print2buff(":::", d);
 			deparse2buff(CADDR(s), d);
 		    }
 		    else {
@@ -1090,20 +1092,21 @@ static void deparse2buff(SEXP s, LocalParseData *d)
 	break;
     case EXTPTRSXP:
     {
-	char tpb[12+sizeof(void *)];
-    	d->sourceable = FALSE;
-	sprintf(tpb, "<pointer: %p>", R_ExternalPtrAddr(s));
+	char tpb[32]; /* need 12+2+2*sizeof(void*) */
+	d->sourceable = FALSE;
+	snprintf(tpb, 32, "<pointer: %p>", R_ExternalPtrAddr(s));
+	tpb[31] = '\0';
 	print2buff(tpb, d);
     }
 	break;
 #ifdef BYTECODE
     case BCODESXP:
-    	d->sourceable = FALSE;
+	d->sourceable = FALSE;
 	print2buff("<bytecode>", d);
 	break;
 #endif
     case WEAKREFSXP:
-    	d->sourceable = FALSE;
+	d->sourceable = FALSE;
 	print2buff("<weak reference>", d);
 	break;
     case S4SXP:
@@ -1120,7 +1123,7 @@ static void deparse2buff(SEXP s, LocalParseData *d)
         print2buff(")", d);
         break;
     default:
-    	d->sourceable = FALSE;
+	d->sourceable = FALSE;
 	UNIMPLEMENTED_TYPE("deparse2buff", s);
     }
 }
@@ -1306,9 +1309,9 @@ static Rboolean src2buff(SEXP sv, int k, LocalParseData *d)
     int i, n;
 
     if (length(sv) > k && !isNull(t = VECTOR_ELT(sv, k))) {
-        PROTECT(t);
+	PROTECT(t);
 
-    	PROTECT(t = lang2(install("as.character"), t));
+	PROTECT(t = lang2(install("as.character"), t));
 	PROTECT(t = eval(t, R_BaseEnv));
 	n = length(t);
 	for(i = 0 ; i < n ; i++) {
@@ -1316,7 +1319,7 @@ static Rboolean src2buff(SEXP sv, int k, LocalParseData *d)
 	    if(i < n-1) writeline(d);
 	}
 	UNPROTECT(3);
-        return TRUE;
+	return TRUE;
     }
     else return FALSE;
 }
@@ -1336,9 +1339,9 @@ static void vec2buff(SEXP v, LocalParseData *d)
     if (length(nv) == 0) nv = R_NilValue;
 
     if (d->opts & USESOURCE)
-   	sv = getAttrib(v, R_SrcrefSymbol);
+	sv = getAttrib(v, R_SrcrefSymbol);
     else
-   	sv = R_NilValue;
+	sv = R_NilValue;
 
     for(i = 0 ; i < n ; i++) {
 	if (i > 0)
@@ -1346,7 +1349,7 @@ static void vec2buff(SEXP v, LocalParseData *d)
 	linebreak(&lbreak, d);
 	if (!isNull(nv) && !isNull(STRING_ELT(nv, i))
 	    && *CHAR(STRING_ELT(nv, i))) { /* length test */
-            /* d->opts = SIMPLEDEPARSE; This seems pointless */
+	    /* d->opts = SIMPLEDEPARSE; This seems pointless */
 	    if( isValidName(translateChar(STRING_ELT(nv, i))) )
 		deparse2buff(STRING_ELT(nv, i), d);
 	    else {
@@ -1370,7 +1373,7 @@ static void args2buff(SEXP arglist, int lineb, int formals, LocalParseData *d)
 
     while (arglist != R_NilValue) {
 	if (TYPEOF(arglist) != LISTSXP && TYPEOF(arglist) != LANGSXP)
-            error(_("badly formed function expression"));
+	    error(_("badly formed function expression"));
 	if (TAG(arglist) != R_NilValue) {
 	    SEXP s = TAG(arglist);
 
